@@ -13,12 +13,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from typing import Iterable, List, Optional, Type
+from typing import Iterable, List, Optional
 
 from fastapi import Depends
 
 from argilla.server.commons.config import TasksFactory
-from argilla.server.services.metrics.models import ServiceBaseTaskMetrics
+from argilla.server.services.datasets import ServiceDataset
 from argilla.server.services.search.model import (
     ServiceSearchResults,
     ServiceSortableField,
@@ -28,7 +28,6 @@ from argilla.server.services.search.service import SearchRecordsService
 from argilla.server.services.storage.service import RecordsStorageService
 from argilla.server.services.tasks.commons import BulkResponse
 from argilla.server.services.tasks.text2text.models import (
-    ServiceText2TextDataset,
     ServiceText2TextQuery,
     ServiceText2TextRecord,
 )
@@ -62,7 +61,7 @@ class Text2TextService:
 
     async def add_records(
         self,
-        dataset: ServiceText2TextDataset,
+        dataset: ServiceDataset,
         records: List[ServiceText2TextRecord],
     ):
         failed = await self.__storage__.store_records(
@@ -74,14 +73,13 @@ class Text2TextService:
 
     def search(
         self,
-        dataset: ServiceText2TextDataset,
+        dataset: ServiceDataset,
         query: ServiceText2TextQuery,
         sort_by: List[ServiceSortableField],
         record_from: int = 0,
         size: int = 100,
         exclude_metrics: bool = True,
     ) -> ServiceSearchResults:
-
         metrics = TasksFactory.find_task_metrics(
             dataset.task,
             metric_ids={
@@ -115,7 +113,7 @@ class Text2TextService:
 
     def read_dataset(
         self,
-        dataset: ServiceText2TextDataset,
+        dataset: ServiceDataset,
         query: Optional[ServiceText2TextQuery] = None,
         id_from: Optional[str] = None,
         limit: int = 1000,
